@@ -18,7 +18,7 @@ _CODE_TPL = """# -*- coding={encoding} -*-
 
 # REGISTER ROUTES BEGIN
 routes = [
-   {routes}
+{routes}
 ]
 # REGISTER ROUTES END
 """
@@ -81,20 +81,19 @@ class Collector:
 
             # 遍历目录，找出所有的 .py 文件
             for (dir_name, dirs, files) in os.walk(route_root):
+                if dir_name == '__pycache__':
+                    continue
                 for file in files:
                     # 不是 .py 文件，忽略
                     if not file.endswith('.py'):
                         continue
 
+                    # 可能是 __init__.py
                     fullname = path.abspath(path.join(dir_name, file))
+
                     # 解析文件
                     self.get_route_defines(route_root, fullname, http_prefix, pkg_prefix, routes, route_env)
 
-                for sub_dir_name in dirs:
-                    pkg_file = path.abspath(path.join(sub_dir_name, '__init__.py'))
-                    if path.exists(pkg_file) and path.isfile(pkg_file):
-                        self.get_route_defines(route_root, pkg_file, http_prefix, pkg_prefix, routes, route_env)
-
         return routes
 
     def get_route_defines(self, route_root, fullname, http_prefix, pkg_prefix, routes, route_env):
@@ -136,9 +135,9 @@ class Collector:
             router_str = router_str.replace('route', '_fake_route')
             define = eval(router_str, route_env)
 
-            # 构造http请求的地址
+            # 构造http请求的地址(将 路径分隔符号 \/ 替换成 . 符号)
             # -3 是为了干掉最后的 .py 字样
-            pkg = re.sub(r'[/\\]', '', path.relpath(fullname, route_define))[0:-3]
+            pkg = re.sub(r'[/\\]', '.', path.relpath(fullname, route_define))[0:-3]
 
             # 当是包时，移除 __init__ 部分
             if path.basename(fullname) == '__init__.py':
