@@ -24,7 +24,7 @@ class WsgiApp:
         if static_map is None:
             static_map = {}
         if context.DEBUG:
-            static_map['/api_assets_for_debug'] = os.path.join(os.path.dirname(__file__), 'api_assets')
+            static_map['/api_assets_for_dev'] = os.path.join(os.path.dirname(__file__), 'api_assets_for_dev')
         self.static_map = static_map
 
         self.url_map = Map([
@@ -44,7 +44,8 @@ class WsgiApp:
             request = HttpRequest(environ, self.context)
             adapter = self.url_map.bind_to_environ(environ)
 
-            if request.path == '/':
+            # 仅在调试时重定向
+            if self.context.DEBUG and request.path == '/':
                 response = Response(status=302, headers={
                     'Location': '/' + self.api_prefix
                 })
